@@ -18,7 +18,7 @@
 readMWRacc <- function(accpth, runchk = TRUE, warn = TRUE){
   
   # na chr not set as NA because of check for na in value range column
-  accdat <- readxl::read_excel(accpth, na = c('NA', ''))
+  accdat <- readxl::read_excel(accpth, na = c('NA', ''), col_types = 'text')
   accdat <- dplyr::mutate(accdat, dplyr::across(-c(`Value Range`), ~ dplyr::na_if(.x, 'na')))
   
   # run checks
